import Foundation

/**
 An object to store the necessary information to authenticate a device to the server.
 */
public struct DeviceAuthentication: Codable {

    /**
     The push token of the device.

     The token is used to uniquely identify the device.
     */
    public let pushToken: PushToken

    /**
     The authentication token of the device.

     This token is created by the server during device registration, and used for all subsequent requests.
     */
    public let authentication: AuthenticationToken

    /**
     Create a device authentication object.

     - Parameter pushToken: The APNs device token
     - Parameter authentication: The authentication token generated by the server
     */
    public init(pushToken: PushToken, authentication: AuthenticationToken) {
        self.pushToken = pushToken
        self.authentication = authentication
    }
}
